@@ -6,6 +6,13 @@ from planqk.commons.reflection import resolve_function, resolve_signature
 
 
 def run_entrypoint(entrypoint: str, entrypoint_arguments: Dict[str, Any]) -> Any:
+    """
+    Run the entrypoint with the given arguments.
+
+    :param entrypoint: The entrypoint to run, e.g. 'user_code.src.program:run'.
+    :param entrypoint_arguments: The arguments to pass to the entrypoint.
+    :return: The return value of the entrypoint.
+    """
     signature = resolve_signature(entrypoint)
 
     logger.debug(f"Parameters in signature: {list(signature.parameters.keys())}")
