@@ -4,8 +4,14 @@ import sys
 
 from loguru import logger
 
+from planqk.commons.constants import LOG_LEVEL_ENV, DEFAULT_LOG_LEVEL
+
 
 class LogHandler(logging.Handler):
+    """
+    A handler class which allows for the use of Loguru with the standard logging module.
+    """
+
     def __init__(self, name: str = None) -> None:
         if name is not None:
             self._logger = logger.patch(lambda record: record.update(name=name))
@@ -32,7 +38,10 @@ class LogHandler(logging.Handler):
 
 
 def init_logging():
-    logging_level = os.environ.get("LOG_LEVEL", "INFO").upper()
+    """
+    Initialize the logging configuration. The logging level is set to the value of the LOG_LEVEL environment variable.
+    """
+    logging_level = os.environ.get(LOG_LEVEL_ENV, DEFAULT_LOG_LEVEL).upper()
 
     logging.getLogger().handlers = [LogHandler()]
     logging.getLogger().setLevel(logging_level)
@@ -40,8 +49,8 @@ def init_logging():
     logger.configure(handlers=[{"sink": sys.stdout, "level": logging_level}])
 
     for stdlib_logger, loguru_handler in (
-            (logging.getLogger(name), LogHandler(name))
-            for name in logging.root.manager.loggerDict
+        (logging.getLogger(name), LogHandler(name))
+        for name in logging.root.manager.loggerDict
     ):
         stdlib_logger.handlers = [loguru_handler]
         stdlib_logger.propagate = False
